[monitoring-plugins] set ssl_version to CURL_SSLVERSION_DEFAULT and ...

Andreas Baumann git at monitoring-plugins.org
Thu Nov 2 16:50:15 CET 2017


 Module: monitoring-plugins
 Branch: feature_check_curl
 Commit: 7a17aa3e91fc2f5faa7e60fa1618eb2a0d2cf85b
 Author: Andreas Baumann <mail at andreasbaumann.cc>
   Date: Thu Nov  2 16:46:20 2017 +0100
    URL: https://www.monitoring-plugins.org/repositories/monitoring-plugins/commit/?id=7a17aa3

set ssl_version to CURL_SSLVERSION_DEFAULT and not CURL_SSLVERSION_TLSv1_0
(since curl 7.56.1 we get an illegal argument error otherwise)

---

 plugins/check_curl.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/plugins/check_curl.c b/plugins/check_curl.c
index 2f58305..db1e9c5 100644
--- a/plugins/check_curl.c
+++ b/plugins/check_curl.c
@@ -1320,10 +1320,10 @@ process_arguments (int argc, char **argv)
 #ifdef LIBCURL_FEATURE_SSL
     enable_ssl:
       use_ssl = TRUE;
       /* ssl_version initialized to CURL_SSLVERSION_TLSv1_0 as a default.
        * Only set if it's non-zero.  This helps when we include multiple
        * parameters, like -S and -C combinations */
-      ssl_version = CURL_SSLVERSION_TLSv1_0;
+      ssl_version = CURL_SSLVERSION_DEFAULT;
       if (c=='S' && optarg != NULL) {
         char *plus_ptr = strchr(optarg, '+');
         if (plus_ptr) {
@@ -1320,10 +1320,10 @@ process_arguments (int argc, char **argv)
     enable_ssl:
       use_ssl = TRUE;
-      /* ssl_version initialized to CURL_SSLVERSION_TLSv1_0 as a default.
+      /* ssl_version initialized to CURL_SSLVERSION_DEFAULT as a default.
        * Only set if it's non-zero.  This helps when we include multiple
        * parameters, like -S and -C combinations */



More information about the Commits mailing list